# Man query

> query - In shell mode, send a enquiry to chatGPT.
In shell mode you need to set the subject, scenario and other parameters using the set command.

By default askGPT shell mode will interpret any line that do not match a command as a query request.

## Usage

`query this is a test`

`this is another test`